@@ -1,6 +1,10 @@
 import copy
+import io
 import json
+import tarfile
+import gzip
 from unittest.mock import patch
+from http import HTTPStatus
 
 import mongomock
 import pytest
@@ -10,7 +14,7 @@ from perun.proxygui.tests.shared_test_data import SHARED_TESTING_CONFIG, ATTRS_M
 
 BAN_IN_DB_1 = {
     "description": None,
-    "facilityId": "1234",
+    "facilityId": "1",
     "id": 1,
     "userId": "57986",
     "validityTo": "1670799600000",
@@ -18,9 +22,9 @@ BAN_IN_DB_1 = {
 
 BAN_IN_DB_2 = {
     "description": "Something serious",
-    "facilityId": "5648",
+    "facilityId": "1",
     "id": 2,
-    "userId": "57986",
+    "userId": "54321",
     "validityTo": "1670799600000",
 }
 
@@ -75,6 +79,9 @@ def client():
     ), patch(
         "perun.utils.ConfigStore.ConfigStore.get_attributes_map",
         return_value=ATTRS_MAP,
+    ), patch(
+        "perun.proxygui.app.init_oidc_rp_handler",
+        return_value=None,
     ):
         cfg = get_config()
         app = get_flask_app(cfg)
@@ -126,10 +133,10 @@ def test_ban_user_all_users_already_banned(
     assert BAN_COLLECTION.count_documents({}) == number_of_bans_in_db
 
 
-@patch("perun.proxygui.api.ban_api.delete_mitre_tokens")
+@patch("perun.proxygui.user_manager.UserManager._delete_mitre_tokens")
 @patch("perun.proxygui.api.ban_api.get_ban_collection")
-@patch("perun.proxygui.api.ban_api.get_satosa_sessions_collection")
-@patch("perun.proxygui.api.ban_api.get_ssp_sessions_collection")
+@patch("perun.proxygui.user_manager.UserManager._get_satosa_sessions_collection")
+@patch("perun.proxygui.user_manager.UserManager._get_ssp_sessions_collection")
 @patch("perun.connector.AdaptersManager.get_user_attributes")
 def test_ban_user_add_new_bans(
     mock_get_user_attributes,
@@ -171,3 +178,51 @@ def test_ban_user_add_new_bans(
         {}
     ) == SATOSA_SESSIONS_COLLECTION.count_documents({"sub": ALLOWED_SUBJECT})
     assert SATOSA_SESSIONS_COLLECTION.find_one({"sub": BANNED_SUBJECT}) is None
+
+
+def test_ban_users_tar_missing_file(
+    client,
+):
+    buffer = io.BytesIO()
+    with tarfile.open(fileobj=buffer, mode="w|gz") as tar:
+        text = b"facility file content"
+        file_data = io.BytesIO(text)
+        info = tarfile.TarInfo(name="FACILITY")
+        info.size = len(text)
+        tar.addfile(info, file_data)
+    tar.name = "sent_data"
+
+    buffer.seek(0)
+    gzipped_data = gzip.compress(buffer.read())
+
+    response = client.put(
+        "/banned-users-generic/", content_type="application/x-tar", data=gzipped_data
+    )
+    assert response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY
+
+
+@patch("perun.proxygui.api.ban_api.get_ban_collection")
+def test_ban_users_tar_update(
+    mock_get_ban_collection,
+    client,
+):
+    mock_get_ban_collection.return_value = BAN_COLLECTION
+    new_bans = {BAN_NOT_IN_DB_1["userId"]: BAN_NOT_IN_DB_1}
+
+    buffer = io.BytesIO()
+    with tarfile.open(fileobj=buffer, mode="w|gz") as tar:
+        text = json.dumps(new_bans).encode("utf-8")
+        file_data = io.BytesIO(text)
+        info = tarfile.TarInfo(name="./banned_facility_users")
+        info.size = len(text)
+        tar.addfile(info, file_data)
+    tar.name = "data"
+
+    buffer.seek(0)
+    gzipped_data = gzip.compress(buffer.read())
+
+    client.put(
+        "/banned-users-generic/", content_type="application/x-tar", data=gzipped_data
+    )
+
+    assert BAN_COLLECTION.count_documents({}) == 1
