@@ -15,6 +15,9 @@ def client():
     ), patch(
         "perun.utils.ConfigStore.ConfigStore.get_attributes_map",
         return_value=SHARED_TESTING_CONFIG,
+    ), patch(
+        "perun.proxygui.app.init_oidc_rp_handler",
+        return_value=None,
     ):
         cfg = get_config()
         app = get_flask_app(cfg)
